"""
    ZFloatMenu
    ==========

JavaScript popup/dropdown menus in Zope
"""
# $Id: ZFloatMenu.py,v 1.7 2002/07/21 20:59:53 adrian Exp $
#
# $Log: ZFloatMenu.py,v $
# Revision 1.7  2002/07/21 20:59:53  adrian
# Changed CMFActionsMenu to default to 'global_tabs' if no categories are specified
#
# Revision 1.6  2002/07/20 23:11:25  adrian
# * Fixed bug in Visuals form where checkboxes did not update correctly
# * Fixed bug in ZFMFolderMenu and CMFPersonalFolderMenu where the javascript for an empty (unlinked) menu was being produced if the folder was not available.
# * Completed and tested CMFActionsMenu
# * Changed "categories" to a tokens field so that you can have a menu listing (For instance) user and global options (Plone does this for the personal menubar).
# * Changed base classes to allow title and target to be method (Both are methods in ZFMFolderMenu and CMFPersonalFolderMenu)
#
# Revision 1.5  2002/07/18 23:10:00  adrian
# * Fixed bug where single quotes break the menu (Filtered out single quotes)
# * Added ZFMFolderMenu
# * Completed and tested ZFMFolderMenu
# * Added CMFPersonalFolderMenu
# * Completed and tested CMFPersonalFolderMenu
# * Added CMFActionsMenu
#
# Revision 1.4  2002/04/16 16:49:52  ahungate
# * Completed setting up rendering - Menus now appear.
# * Set the colour scheme to be compatible with Plone.
# * Added support for submenus that list folder contents - Needs work.
#
# Revision 1.3  2002/04/15 22:19:02  adrian
# *** empty log message ***
#
# Revision 1.2  2002/04/15 16:32:36  ahungate
# Using javascript menu from http://www.milonic.co.uk/menu to provide
# visuals. Started coding property editors, and some javascript autogeneration.
#
# Revision 1.1.1.1  2002/02/03 17:07:16  root
#
#
# Revision 1.4  2001/11/29 11:38:13  adrian
# no message
#
# Revision 1.3  2001/11/02 00:28:53  adrian
# no message
#
# Revision 1.2  2001/10/31 23:53:01  adrian
# no message
#
# Revision 1.1  2001/10/31 21:42:03  adrian
# Initial development
#
#
__version__ = '$Revision: 1.7 $'[11:-2]

import Globals
import ImageFile
import OFS
import App.Management
import AccessControl
import urllib
from Globals import package_home
import os
import string

manage_addZFloatMenuForm = Globals.DTMLFile('www/addZFloatMenu', globals())
def manage_addZFloatMenu(self, id='', title='', submit=None, REQUEST=None):
    """ """
    obj = ZFloatMenu(str(id), str(title))
    self._setObject(obj.getId(), obj)
    if REQUEST is not None:
        try: u=self.DestinationURL()
        except: u=REQUEST['URL1']
        if submit==" Add and Edit ": u="%s/%s" % (u, urllib.quote(obj.getId()))
        REQUEST.RESPONSE.redirect(u+'/manage_workspace')
    return ''

class _menuBase(
        OFS.PropertyManager.PropertyManager,
        AccessControl.Role.RoleManager,
    ):
    """ Base class for ZFM and ZFMsm """
    all_meta_types = meta_types = (
        {'name': 'ZFM Sub Menu', 'action': 'manage_addZFMSubMenuForm'},
        {'name': 'ZFM Menu Item', 'action': 'manage_addZFMMenuItemForm'},
        {'name': 'ZFM Folder Menu', 'action': 'manage_addZFMFolderMenuForm'},
        {'name': 'CMF Personal Folder Menu', 'action': 'manage_addCMFPersonalFolderMenuForm'},
        {'name': 'CMF Actions Menu', 'action': 'manage_addCMFActionsMenuForm'},
    )
    _properties	=   (
        {'id': 'title', 'type': 'string', 'mode': 'w'},
        {'id': 'sep_after', 'type': 'boolean', 'mode': 'w'},
        {'id': 'menuTop', 'type': 'string', 'mode':'w'},
        {'id': 'menuLeft', 'type': 'string', 'mode':'w'},
        {'id': 'menuWidth', 'type': 'string', 'mode':'w'},
        {'id': 'menuBorderWidth', 'type': 'string', 'mode':'w'},
        {'id': 'menuScreenPos', 'type': 'string', 'mode':'w'},
        {'id': 'menuAlignment', 'type': 'string', 'mode':'w'},
        {'id': 'menuHoriz', 'type': 'boolean', 'mode': 'w'},
        {'id': 'menuSubImagePos', 'type': 'string', 'mode':'w'},
    )
    manage_options = (
        OFS.PropertyManager.PropertyManager.manage_options
    )
    title = ''
    sep_after = 1
    menuTop = ''
    menuLeft = ''
    menuWidth = ''
    menuBorderWidth = '1'
    menuScreenPos = 'left'
    menuTopLevel = 0
    menuAlignment = 'left'
    menuHoriz = 0
    menuSubImagePos = ''

    def renderMenu(self, parentId):
        """ Add this submenu """
        myId = "%s_%s" % (parentId, self.getId())
        subs = ""
        js = """addmenu(menu=["%s", %s, %s, %s, %s, "%s", menuStyle, %d, "%s", menuEffect, %d, %d, , "%s", , , %d, , , , ,
""" % ( myId, self.menuTop, self.menuLeft, self.menuWidth,
        self.menuBorderWidth, self.menuScreenPos, self.menuTopLevel and 1 or 0,
        self.menuAlignment, self.menuFollowScroll and 1 or 0,
        self.menuHoriz and 1 or 0, self.menuSubImagePos,
        self.menuOnClick and 1 or 0, )
        objs = self.listMenuObjects()
        objs.sort(lambda a,b: cmp(a.getId(), b.getId()))
        for obj in objs:
            js = js + str(self.renderSubItem(obj, myId))
            subs = subs + str(self.renderSubMenu(obj, myId))
        js = js + """]);
""" + subs
        return js

    def listMenuObjects(self):
        """ List the items that should be in this sub menu """
        return self.objectValues()

    def renderSubMenu(self, obj, myId):
        """ Return a rendered subMenu """
        return obj.renderMenu(myId)

    def renderSubItem(self, obj, myId):
        """ Return a rendered subItem """
        return obj.renderItem(myId)

    def renderItem(self, parentId):
        """ Render a link to this menu as a submenu (Called by parent) """
        title = self.title
        if callable(title):
            title = title()
        title = string.replace(title, '"', "'")
        target = self.target
        if callable(target):
            target = target()
        target = string.replace(target, '"', '\"')
        status = string.replace(self.status, '"', "'")
        js = ""","%s","show-menu=%s",%s,"%s",%d
""" % (title, "%s_%s" % (parentId, self.getId(), ),
       target and '"%s"' % target or '',
       status or target, self.sep_after and 1 or 0, )
        return js

    manage_addZFMSubMenuForm = Globals.DTMLFile('www/addZFMSubMenu', globals())
    def manage_addZFMSubMenu(self, id, title, target, submit=' Add ', REQUEST=None):
        """ """
        obj = ZFMSubMenu(str(id), str(title), str(target))
        self._setObject(obj.getId(), obj)
        if REQUEST is not None:
            try: u=self.DestinationURL()
            except: u=REQUEST['URL1']
            if submit==" Add and Edit ": u="%s/%s" % (u, urllib.quote(obj.getId()))
            REQUEST.RESPONSE.redirect(u+'/manage_workspace')
        return ''

    manage_addZFMMenuItemForm = Globals.DTMLFile('www/addZFMMenuItem', globals())
    def manage_addZFMMenuItem(self, id, title, target, submit=' Add ', REQUEST=None):
        """ """
        obj = ZFMMenuItem(str(id), str(title), str(target))
        self._setObject(obj.getId(), obj)
        if REQUEST is not None:
            try: u=self.DestinationURL()
            except: u=REQUEST['URL1']
            if submit==" Add and Edit ": u="%s/%s" % (u, urllib.quote(obj.getId()))
            REQUEST.RESPONSE.redirect(u+'/manage_workspace')
        return ''

    manage_addZFMFolderMenuForm = Globals.DTMLFile('www/addZFMFolderMenu', globals())
    def manage_addZFMFolderMenu(self, id, folder, listed_types, submit=' Add ', REQUEST=None):
        """ """
        obj = ZFMFolderMenu(str(id), str(folder), listed_types)
        self._setObject(obj.getId(), obj)
        if REQUEST is not None:
            try: u=self.DestinationURL()
            except: u=REQUEST['URL1']
            if submit==" Add and Edit ": u="%s/%s" % (u, urllib.quote(obj.getId()))
            REQUEST.RESPONSE.redirect(u+'/manage_workspace')
        return ''

    manage_addCMFPersonalFolderMenuForm = Globals.DTMLFile('www/addCMFPersonalFolderMenu', globals())
    def manage_addCMFPersonalFolderMenu(self, id, folder, listed_types, submit=' Add ', REQUEST=None):
        """ """
        obj = CMFPersonalFolderMenu(str(id), str(folder), listed_types)
        self._setObject(obj.getId(), obj)
        if REQUEST is not None:
            try: u=self.DestinationURL()
            except: u=REQUEST['URL1']
            if submit==" Add and Edit ": u="%s/%s" % (u, urllib.quote(obj.getId()))
            REQUEST.RESPONSE.redirect(u+'/manage_workspace')
        return ''

    manage_addCMFActionsMenuForm = Globals.DTMLFile('www/addCMFActionsMenu', globals())
    def manage_addCMFActionsMenu(self, id, title, category, submit=' Add ', REQUEST=None):
        """ """
        obj = CMFActionsMenu(str(id), str(title), str(category))
        self._setObject(obj.getId(), obj)
        if REQUEST is not None:
            try: u=self.DestinationURL()
            except: u=REQUEST['URL1']
            if submit==" Add and Edit ": u="%s/%s" % (u, urllib.quote(obj.getId()))
            REQUEST.RESPONSE.redirect(u+'/manage_workspace')
        return ''

Globals.default__class_init__(_menuBase)

class _itemBase(
        OFS.PropertyManager.PropertyManager,
        AccessControl.Role.RoleManager,
    ):
    """ """
    _properties =   (
        {'id': 'title', 'type': 'string', 'mode': 'w'},
        {'id': 'status', 'type': 'string', 'mode': 'w'},
        {'id': 'target', 'type': 'string', 'mode': 'w'},
    )
    manage_options = (
        OFS.PropertyManager.PropertyManager.manage_options
    )
    title = ''
    status = ''
    target = ''

    def renderMenu(self, parentId):
        """ Do nothing for items """
        return ''

    def renderItem(self, parentId):
        """ Render a link to a target """
        title = self.title
        if callable(title):
            title = title()
        title = string.replace(title, '"', "'")
        target = self.target
        if callable(target):
            target = target()
        target = string.replace(target, '"', '\"')
        status = string.replace(self.status, '"', "'")
        js = ""","%s","%s",,"%s",%d
""" % (title, target, status or target,
       self.sep_after and 1 or 0, )
        return js

Globals.default__class_init__(_itemBase)

class ZFloatMenu(
        _menuBase,
        OFS.ObjectManager.ObjectManager,
        OFS.SimpleItem.SimpleItem,
    ):
    """ """
    meta_type       = 'Z Float Menu'
    id              = 'ZFloatMenu'
    icon            = 'misc_/ZFloatMenu/ZFloatMenu'
    manage_visuals = Globals.DTMLFile('www/visuals', globals())
    manage_preview = Globals.DTMLFile('www/preview', globals())
    manage_options  = (
        OFS.ObjectManager.ObjectManager.manage_options +
        _menuBase.manage_options +
        (
            {'label': 'Visual Details', 'action': 'manage_visuals',
             'help': ('ZFloatMenu', 'manage_visuals.stx')},
            {'label': 'Preview', 'action': 'manage_preview',
             'help': ('ZFloatMenu', 'manage_preview.stx')},
        ) +
        OFS.SimpleItem.SimpleItem.manage_options
    )
    __ac_permissions__ = (
        ('Manage Z Float Menus',
            ('manage_visuals', 'manage_changeVisuals', ),
            ('Manager', ),
        ),
    )
    menuTopLevel = 1
    menuFollowScroll = 0
    menuOnClick = 0
    menuHoriz = 1
    _properties =   (
        _menuBase._properties +
        (
            {'id': 'menuFollowScroll', 'type': 'boolean', 'mode':'w'},
            {'id': 'menuOnClick', 'type': 'boolean', 'mode': 'w'},
            {'id': 'timegap', 'type':'int', 'mode':'w'},
            {'id': 'followspeed', 'type':'int', 'mode':'w'},
            {'id': 'followrate', 'type':'int', 'mode':'w'},
            {'id': 'suboffset_top', 'type':'int', 'mode':'w'},
            {'id': 'suboffset_left', 'type':'int', 'mode':'w'},
        )
    )
    timegap = 500
    followspeed = 5
    followrate = 40
    suboffset_top = 10
    suboffset_left = 10
    visuals = (
        {'id': 'mouse_off_font_colour', 'type': 'colour', },
        {'id': 'mouse_off_back_colour', 'type': 'colour', },
        {'id': 'mouse_on_font_colour',  'type': 'colour', },
        {'id': 'mouse_on_back_colour',  'type': 'colour', },
        {'id': 'menu_border_colour',    'type': 'colour', },
        {'id': 'font_size',             'type': 'string', },
        {'id': 'font_style',            'type': 'string', },
        {'id': 'font_weight',           'type': 'string', },
        {'id': 'font_family',           'type': 'string', },
        {'id': 'menu_item_padding',     'type': 'string', },
        {'id': 'sub_menu_image',        'type': 'string', },
        {'id': 'menu_3d_border',        'type': 'boolean', },
        {'id': 'menu_3d_high_colour',   'type': 'colour', },
        {'id': 'menu_3d_low_colour',    'type': 'colour', },
        {'id': 'curr_page_font_colour', 'type': 'colour', },
        {'id': 'curr_page_back_colour', 'type': 'colour', },
        {'id': 'horiz_sub_menu_image',  'type': 'string', },
        {'id': 'menu_head_font_colour', 'type': 'colour', },
        {'id': 'menu_head_back_colour', 'type': 'colour', },
    )
    mouse_off_font_colour   = '#436976'
    mouse_off_back_colour   = '#ffffff'
    mouse_on_font_colour    = '#436976'
    mouse_on_back_colour    = '#dee7ec'
    menu_border_colour      = '#436976'
    font_size               = '12px'
    font_style	            = 'normal'
    font_weight             = 'normal'
    font_family             = 'Verdana, Arial, Helvetica, sans-serif'
    menu_item_padding       = '1 12 1 5'
    sub_menu_image          = 'misc_/ZFloatMenu/ZFMArrowR'
    menu_3d_border          = 0
    menu_3d_high_colour     = '#e0e0e0'
    menu_3d_low_colour      = '#808080'
    curr_page_font_colour   = '#436976'
    curr_page_back_colour   = '#ffffff'
    horiz_sub_menu_image    = 'misc_/ZFloatMenu/ZFMArrowD'
    menu_head_font_colour   = '#436976'
    menu_head_back_colour   = '#ffffff'

    def __init__(self, id, title=''):
        """ """
        self.id = str(id)
        self.title = str(title)

    def manage_changeVisuals(self, REQUEST):
        """ """
        for item in self.visuals:
            k = item['id']
            v = REQUEST.get(k)
            setattr(self, k, v)
        try: u=self.DestinationURL()
        except: u=REQUEST['URL1']
        REQUEST.RESPONSE.redirect(u+'/manage_visuals')

    def __call__(self, REQUEST=None):
        """ Insert menu code, create root and call children """
        if not REQUEST:
            REQUEST=self.REQUEST
        js = """
<!-- Start menu script -->"""
        if not REQUEST.has_key('ZFM_Done'):
            js = js + """
<script language="javascript"><!--
menunum=0;
dumpedmenunum=0;
menus=new Array();
_d=document;
function addmenu() {
    menunum++;
    menus[menunum]=menu;
}
function dumpmenus() {
    mt="<script language=javascript>";
    for(a=dumpedmenunum+1;a<menus.length;a++) {
        mt+=" menu"+a+"=menus["+a+"];";
    }
    dumpedmenunum=menus.length-1;
    mt+="<\/script>";
    _d.write(mt);
}
//--></script>"""
        if 1==0:
            js = js + """
<script language="javascript" src="%s/ZFMRender" type="text/javascript"></script>""" % self.absolute_url()
        else:
            js = js + """
<script language="javascript"><!--
%s
//--></script>""" % self.ZFMRender(inline=1);
        if not REQUEST.has_key('ZFM_Done'):
            js = js + """
<script language="javascript" src="%s/ZFMScript" type="text/javascript"></script>""" % self.absolute_url()
            REQUEST.set('ZFM_Done', 1)
        js = js + """
<!-- End menu script -->"""
        return js

    def ZFMScript(self):
        """ output the mmenu.js file """
        path = os.path.join(package_home(globals()), "www/mmenu.js")
        file=open(path, 'rb')
        data=file.read()
        file.close()
        self.REQUEST.RESPONSE.setHeader('content-type', 'text/javascript')
        return data

    def ZFMRender(self, inline=0):
        """ Produce the 'per menu' javascript """
        js = """
menuEffect="";
timegap=%d;
followspeed=%d;
followrate=%d;
suboffset_top=%d;
suboffset_left=%d;

// Menu Visuals
menuStyle=["%s", "%s", "%s", "%s", "%s", "%s", "%s", "%s", "%s", "%s", "%s", %s, "%s", "%s", "%s", "%s", "%s", "%s", "%s", ];
""" % (self.timegap, self.followspeed, self.followrate,
       self.suboffset_top, self.suboffset_left,
       self.mouse_off_font_colour, self.mouse_off_back_colour,
       self.mouse_on_font_colour, self.mouse_on_back_colour,
       self.menu_border_colour, self.font_size, self.font_style,
       self.font_weight, self.font_family, self.menu_item_padding,
       self.sub_menu_image, self.menu_3d_border and "1" or "",
       self.menu_3d_high_colour, self.menu_3d_low_colour,
       self.curr_page_font_colour, self.curr_page_back_colour,
       self.horiz_sub_menu_image, self.menu_head_font_colour,
       self.menu_head_back_colour, )
        tmp = self.renderMenu("ZFM")
        js = js + string.replace(tmp, "'", "")
        js = js + """
dumpmenus();
"""
        if not inline:
            self.REQUEST.RESPONSE.setHeader('content-type', 'text/javascript')
        return js

    def render(self, REQUEST=None):
        """ """
        return self(REQUEST)

Globals.default__class_init__(ZFloatMenu)

class ZFMSubMenu(
        _menuBase,
        _itemBase,
        OFS.ObjectManager.ObjectManager,
        OFS.SimpleItem.SimpleItem,
    ):
    """ """
    meta_type       = 'ZFM Sub Menu'
    id              = 'ZFMSubMenu'
    icon            = 'misc_/ZFloatMenu/ZFMSubMenu'
    manage_options  = (
        OFS.ObjectManager.ObjectManager.manage_options +
        _menuBase.manage_options +
        _itemBase.manage_options[1:] +
        OFS.SimpleItem.SimpleItem.manage_options
    )
    _properties	=   (
        _itemBase._properties +
        _menuBase._properties[1:]
    )
    target = ''

    def __init__(self, id, title='', target=''):
        """ """
        self.id = str(id)
        self.title = str(title)
        self.target = str(target)

Globals.default__class_init__(ZFMSubMenu)

class ZFMMenuItem(
        _itemBase,
        OFS.SimpleItem.SimpleItem,
    ):
    """ """
    meta_type       = 'ZFM Menu Item'
    id              = 'ZFMMenuItem'
    icon            = 'misc_/ZFloatMenu/ZFMMenuItem'
    manage_options  = (
        _itemBase.manage_options +
        OFS.SimpleItem.SimpleItem.manage_options
    )
    _properties	=   (
        _itemBase._properties
    )
    target = ''

    def __init__(self, id, title='', target=''):
        """ """
        self.id = str(id)
        self.title = str(title)
        self.target = str(target)

Globals.default__class_init__(ZFMMenuItem)

class ZFMFolderMenu(
        _menuBase,
        _itemBase,
        OFS.SimpleItem.SimpleItem,
    ):
    """ A submenu that gets it's contents from a folder
        optionally listing only certain meta_types """
    meta_type       = 'ZFM Folder Menu'
    id              = 'ZFMFolderMenu'
    icon            = 'misc_/ZFloatMenu/ZFMFolderMenu'
    _properties     =   (
        _itemBase._properties[1:2] +
        (
            {'id': 'folder', 'type': 'string', 'mode': 'w', },
            {'id': 'listedTypes', 'type': 'lines', 'mode': 'w', },
        ) +
        _menuBase._properties[1:]
    )
    folder = ''
    listedTypes = []

    def __init__(self, id, folder='', listed_types=[]):
        """ """
        self.id = str(id)
        self.folder = str(folder)
        self.listedTypes = listed_types

    def target(self):
        """ Return the URL of the target for this menu """
        obj = self.getFolderObject()
        if not obj:
            return ""
        return obj.absolute_url()

    def getFolderObject(self):
        """ Return the folderish object in question or None to skip """
        obj = self.aq_parent.restrictedTraverse(self.folder, None)
        return obj

    def renderMenu(self, parentId):
        """ """
        if not self.getFolderObject():
            return ""
        return _menuBase.renderMenu(self, parentId)

    def listMenuObjects(self):
        """ List the items that should be in this sub menu """
        obj = self.getFolderObject()
        if not obj:
            return []
        types = []
        for t in self.listedTypes:
            if t:
                types.append(t)
        if not types:
            types = None
        obList = obj.objectValues(types)
        return obList

    def renderSubMenu(self, obj, myId):
        """ Return a rendered subMenu """
        return ''

    def title(self):
        """ Return a good menu title for this folder object """
        obj = self.getFolderObject()
        if not obj:
            return ""
        return obj.title_or_id()

    def renderSubItem(self, obj, parentId):
        """ Render a link to a submenu """
        title = obj.title
        if callable(title):
            title = title()
        title = string.replace(title, '"', "'")
        id = string.replace(obj.getId(), '"', "'")
        target = string.replace(obj.absolute_url(), '"', "'")
        js = ""","%s","%s",,"%s",%d
""" % (title or id, target, title or target,
       self.sep_after and 1 or 0, )
        return js

    def renderItem(self, parentId):
        """ Render a link to this menu as a submenu (Called by parent) """
        obj = self.getFolderObject()
        if not obj:
            return ""
        return _menuBase.renderItem(self, parentId)

Globals.default__class_init__(ZFMFolderMenu)

class CMFPersonalFolderMenu(ZFMFolderMenu):
    """
        Render a menu for a CMF Members personal folder (Or a folder within it)
        This will not do much in a menu outside of a CMF Site.
    """
    meta_type       = 'CMF Personal Folder Menu'
    id              = 'CMFPersonalFolderMenu'
    icon            = 'misc_/ZFloatMenu/CMFPersonalFolderMenu'

    def getFolderObject(self):
        """ Return the correct folder, relative to the current users
            CMF Member Folder, or None to skip """
        p_mem = getattr(self, 'portal_membership', None)
        if not p_mem:
            return None
        homeFolder=p_mem.getHomeFolder()
        if not homeFolder:
            return None
        obj = homeFolder.restrictedTraverse(self.folder, None)
        return obj

Globals.default__class_init__(CMFPersonalFolderMenu)

class CMFActionsMenu(
        _menuBase,
        _itemBase,
        OFS.SimpleItem.SimpleItem,
    ):
    """
        Render a menu for a particular class of CMF Actions.
        This will not do much in a menu outside of a CMF Site.
    """
    meta_type       = 'CMF Actions Menu'
    id              = 'CMFActionsMenu'
    icon            = 'misc_/ZFloatMenu/CMFActionsMenu'
    _properties     =   (
        _itemBase._properties[:-1] +
        (
            {'id': 'category', 'type': 'tokens', 'mode': 'w', },
        ) +
        _menuBase._properties[1:]
    )
    title = ""
    category = ""

    class _actionItem:
        " This object represents an Action "

        def __init__(self, id, title, url):
            " Create a new _actionItem "
            self.id = id
            self.title = title
            self.url = url

        def getId(self):
            " "
            return self.id

    def __init__(self, id, title, category):
        """ """
        self.id = str(id)
        self.title = str(title)
        self.category = str(category)

    def listMenuObjects(self):
        """ List the items that should be in this sub menu """
        id = 0
        obList = []
        pa = getattr(self.aq_parent, "portal_actions", None)
        if pa:
            lffa = pa.listFilteredActionsFor(self.aq_parent)
            for cat in self.category or ['global_tabs']:
                if lffa.has_key(cat):
                    for item in lffa[cat]:
                        if item['visible']:
                            obList.append(
                                self._actionItem(
                                    "%03.0d" % id,
                                    item['name'],
                                    item['url'],
                                )
                            )
                            id = id + 1
        return obList

    def renderSubMenu(self, obj, myId):
        """ Return a rendered subMenu """
        return ''

    def renderSubItem(self, obj, parentId):
        """ Render a link to a submenu """
        title = string.replace(obj.title, '"', "'")
        id = string.replace(obj.getId(), '"', "'")
        target = string.replace(obj.url, '"', "'")
        js = ""","%s","%s",,"%s",%d
""" % (title, target, title,
       self.sep_after and 1 or 0, )
        return js

    def renderMenu(self, parentId):
        """ """
        if not getattr(self.aq_parent, "portal_actions", None):
            return ""
        return _menuBase.renderMenu(self, parentId)

    def renderItem(self, parentId):
        """ Render a link to this menu as a submenu (Called by parent) """
        if not getattr(self.aq_parent, "portal_actions", None):
            return ""
        return _menuBase.renderItem(self, parentId)

Globals.default__class_init__(CMFActionsMenu)
